@@ -15,11 +15,8 @@ exportSurveyParticipants <- function(rcon,
 exportSurveyParticipants.redcapApiConnection <- function(rcon, 
                                                          instrument     = NULL, 
                                                          event          = NULL,
-                                                         ...,
-                                                         error_handling = getOption("redcap_error_handling"),
-                                                         config         = list(), 
-                                                         api_param      = list()){
-  
+                                                         ...)
+{
    ##################################################################
   # Argument Validation
   
@@ -40,20 +37,7 @@ exportSurveyParticipants.redcapApiConnection <- function(rcon,
                               any.miss = FALSE, 
                               null.ok = TRUE, 
                               add = coll)
-  
-  error_handling <- checkmate::matchArg(x = error_handling, 
-                                        choices = c("null", "error"), 
-                                        add = coll, 
-                                        .var.name = "error_handling")
-  
-  checkmate::assert_list(x = config, 
-                         names = "named", 
-                         add = coll)
-  
-  checkmate::assert_list(x = api_param, 
-                         names = "named", 
-                         add = coll)
-  
+
   checkmate::reportAssertions(coll)
   
   checkmate::assert_subset(x = instrument, 
@@ -71,23 +55,13 @@ exportSurveyParticipants.redcapApiConnection <- function(rcon,
    ##################################################################
   # Make API Body List
   
-  body <- list(token=rcon$token, 
-               instrument = instrument,
+  body <- list(instrument = instrument,
                event = event,
                content = 'participantList',
                format = 'csv', 
                returnFormat = 'csv')
-  
-  body <- body[lengths(body) > 0]
-  
+
    ##################################################################
   # Call the API
-  
-  response <- makeApiCall(rcon, 
-                          body = c(body, api_param), 
-                          config = config)
-  
-  if (response$status_code != 200) return(redcapError(response, error_handling))
-  
-  as.data.frame(response)
+  as.data.frame(makeApiCall(rcon, body, ...))
 }
