@@ -423,11 +423,9 @@ data_frame_to_string <- function(data)
 {
   paste0(
     utils::capture.output(
-      utils::write.table(data, 
-                         sep = ",",
-                         col.names = TRUE,
-                         row.names = FALSE,
-                         na = "")
+      utils::write.csv(data,
+                       row.names = FALSE,
+                       na = "")
     ),
     collapse = "\n"
   )
