@@ -1,5 +1,5 @@
 # validate_import_form_complete -------------------------------------
-# Tests to perform 
+# Tests to perform
 # * The following values are mapped
 #     Incomplete to 0
 #     Unverified to 1
@@ -11,28 +11,28 @@
 validate_import_form_complete <- function(x, field_name, logfile)
 {
   x <- as.character(x)
-  x <- gsub(pattern = "Incomplete", 
-            replacement = "0", 
+  x <- gsub(pattern = "Incomplete",
+            replacement = "0",
             x = x)
-  x <- gsub(pattern = "Unverified", 
-            replacement = "1", 
+  x <- gsub(pattern = "Unverified",
+            replacement = "1",
             x = x)
-  x <- gsub(pattern = "Complete", 
-            replacement = "2", 
+  x <- gsub(pattern = "Complete",
+            replacement = "2",
             x = x)
   x <- trimws(x)
-  
+
   w <- which((!x %in% 0:2) & !is.na(x))
   x[w] <- NA
-  
+
   print_validation_message(
-    field_name, 
+    field_name,
     indices = w,
     message = paste0("Values(s) must be one of: 0, 1, 2, ",
-                     "Incomplete, Unverified, or Complete.\n", 
+                     "Incomplete, Unverified, or Complete.\n",
                      "Value not imported"),
     logfile = logfile)
-  
+
   x
 }
 
@@ -48,10 +48,10 @@ validate_import_date <- function(x, field_name, field_min, field_max, logfile)
 {
   if (isTRUE(trimws(field_min) == "today")) field_min = format(Sys.Date())
   if (isTRUE(trimws(field_min) == "now")) field_min = format(Sys.time())
-  
+
   if (isTRUE(trimws(field_max) == "today")) field_max = format(Sys.Date())
   if (isTRUE(trimws(field_max) == "now")) field_max = format(Sys.time())
-  
+
   x_orig <- x
   if (!inherits(x, "Date") && !inherits(x, "POSIXct"))
   {
@@ -62,7 +62,7 @@ validate_import_date <- function(x, field_name, field_min, field_max, logfile)
                                                  "dmy", "dmy HMS"))
     )
   }
-  
+
   w_low <- which(as.POSIXct(x) < as.POSIXct(field_min, origin = "1970-01-01"))
   print_validation_message(
     field_name,
@@ -71,7 +71,7 @@ validate_import_date <- function(x, field_name, field_min, field_max, logfile)
                      format(field_min, format = "%Y-%m-%d")),
     logfile = logfile
   )
-  
+
   w_high <- which(as.POSIXct(x) > as.POSIXct(field_max, origin = "1970-01-01"))
   print_validation_message(
     field_name,
@@ -80,20 +80,20 @@ validate_import_date <- function(x, field_name, field_min, field_max, logfile)
                      format(field_max, format = "%Y-%m-%d")),
     logfile = logfile
   )
-  
-  
+
+
   x <- format(x, format = "%Y-%m-%d")
-  
+
   w <- which(is.na(x) & !x_orig %in% c('', NA))
-  
+
   print_validation_message(
-    field_name, 
+    field_name,
     indices = w,
     message = paste0("Value(s) must have POSIXct class, Date class, ",
-                     "or character class in ymd, mdy, or dmy format (with optional HMS).\n", 
+                     "or character class in ymd, mdy, or dmy format (with optional HMS).\n",
                      "Value not imported"),
     logfile = logfile)
-  
+
   x
 }
 
@@ -108,21 +108,21 @@ validate_import_datetime <- function(x, field_name, field_min, field_max, logfil
 {
   if (isTRUE(trimws(field_min) == "today")) field_min = format(Sys.Date())
   if (isTRUE(trimws(field_min) == "now")) field_min = format(Sys.time())
-  
+
   if (isTRUE(trimws(field_max) == "today")) field_max = format(Sys.Date())
   if (isTRUE(trimws(field_max) == "now")) field_max = format(Sys.time())
-  
+
   x_orig <- x
   if (!inherits(x, "Date") && !inherits(x, "POSIXct"))
   {
     suppressWarnings(
       x <- lubridate::parse_date_time(x = x,
-                                      orders = c("ymd", "ymd HMS", "ymd HM", 
+                                      orders = c("ymd", "ymd HMS", "ymd HM",
                                                  "mdy", "mdy HMS", "mdy HM",
                                                  "dmy", "dmy HMS", "dmy HM"))
     )
   }
-  
+
   w_low <- which(as.POSIXct(x) < as.POSIXct(field_min, origin = "1970-01-01"))
   print_validation_message(
     field_name,
@@ -131,7 +131,7 @@ validate_import_datetime <- function(x, field_name, field_min, field_max, logfil
                      format(field_min, format = "%Y-%m-%d %H:%M")),
     logfile = logfile
   )
-  
+
   w_high <- which(as.POSIXct(x) > as.POSIXct(field_max, origin = "1970-01-01"))
   print_validation_message(
     field_name,
@@ -140,19 +140,19 @@ validate_import_datetime <- function(x, field_name, field_min, field_max, logfil
                      format(field_max, format = "%Y-%m-%d %H:%M")),
     logfile = logfile
   )
-  
+
   x <- format(x, format = "%Y-%m-%d %H:%M")
-  
+
   w <- which(is.na(x) & !x_orig %in% c('', NA))
-  
+
   print_validation_message(
-    field_name, 
+    field_name,
     indices = w,
     message = paste0("Value(s) must have POSIXct class, Date class, ",
-                     "or character class in ymd, mdy, or dmy format (with optional HMS).\n", 
+                     "or character class in ymd, mdy, or dmy format (with optional HMS).\n",
                      "Value not imported"),
     logfile = logfile)
-  
+
   x
 }
 
@@ -167,10 +167,10 @@ validate_import_datetime_seconds <- function(x, field_name, field_min, field_max
 {
   if (isTRUE(trimws(field_min) == "today")) field_min = format(Sys.Date())
   if (isTRUE(trimws(field_min) == "now")) field_min = format(Sys.time())
-  
+
   if (isTRUE(trimws(field_max) == "today")) field_max = format(Sys.Date())
   if (isTRUE(trimws(field_max) == "now")) field_max = format(Sys.time())
-  
+
   x_orig <- x
   if (!inherits(x, "Date") && !inherits(x, "POSIXct"))
   {
@@ -181,7 +181,7 @@ validate_import_datetime_seconds <- function(x, field_name, field_min, field_max
                                                  "dmy", "dmy HMS"))
     )
   }
-  
+
   w_low <- which(as.POSIXct(x) < as.POSIXct(field_min))
   print_validation_message(
     field_name,
@@ -190,7 +190,7 @@ validate_import_datetime_seconds <- function(x, field_name, field_min, field_max
                      format(field_min, format = "%Y-%m-%d %H:%M:%S")),
     logfile = logfile
   )
-  
+
   w_high <- which(as.POSIXct(x) > as.POSIXct(field_max))
   print_validation_message(
     field_name,
@@ -199,19 +199,19 @@ validate_import_datetime_seconds <- function(x, field_name, field_min, field_max
                      format(field_max, format = "%Y-%m-%d %H:%M:%S")),
     logfile = logfile
   )
-  
+
   x <- format(x, format = "%Y-%m-%d %H:%M:%S")
-  
+
   w <- which(is.na(x) & !x_orig %in% c('', NA))
-  
+
   print_validation_message(
-    field_name, 
+    field_name,
     indices = w,
     message = paste0("Value(s) must have POSIXct class, Date class, ",
-                     "or character class in ymd, mdy, or dmy format (with optional HMS).\n", 
+                     "or character class in ymd, mdy, or dmy format (with optional HMS).\n",
                      "Value not imported"),
     logfile = logfile)
-  
+
   x
 }
 
@@ -225,10 +225,10 @@ validate_import_datetime_seconds <- function(x, field_name, field_min, field_max
 validate_import_time <- function(x, field_name, field_min, field_max, logfile)
 {
   x <- as.character(x)
-  
+
   w_invalid <- !grepl("^(\\d{2}:\\d{2}:00|\\d{2}:\\d{2})$", x)
   x[w_invalid] <- NA
-  
+
   count_minute <- function(t)
   {
     if (is.na(t)) return(NA_real_)
@@ -239,7 +239,7 @@ validate_import_time <- function(x, field_name, field_min, field_max, logfile)
   }
 
   total_min <- vapply(x, count_minute, numeric(1))
-  
+
   print_validation_message(
     field_name,
     indices = which(total_min < count_minute(field_min)),
@@ -247,7 +247,7 @@ validate_import_time <- function(x, field_name, field_min, field_max, logfile)
                      field_min),
     logfile = logfile
   )
-  
+
   print_validation_message(
     field_name,
     indices = which(total_min > count_minute(field_max)),
@@ -255,7 +255,7 @@ validate_import_time <- function(x, field_name, field_min, field_max, logfile)
                      field_max),
     logfile = logfile
   )
-  
+
   print_validation_message(
     field_name,
     indices = which(w_invalid),
@@ -264,7 +264,7 @@ validate_import_time <- function(x, field_name, field_min, field_max, logfile)
                      field_min),
     logfile = logfile
   )
-  
+
   substr(x, 1, 5)
 }
 
@@ -278,13 +278,13 @@ validate_import_time <- function(x, field_name, field_min, field_max, logfile)
 validate_import_time_mm_ss <- function(x, field_name, field_min, field_max, logfile)
 {
   x <- as.character(x)
-  
-  x[grepl("^\\d{2}:\\d{2}:\\d{2}$", x)] <- 
+
+  x[grepl("^\\d{2}:\\d{2}:\\d{2}$", x)] <-
     sub("^\\d{2}:", "", x[grepl("^\\d{2}:\\d{2}:\\d{2}$", x)])
-  
+
   w_invalid <- !grepl("^\\d{2}:\\d{2}$", x) & !is.na(x)
   x[w_invalid] <- NA
-  
+
   count_second <- function(t)
   {
     if (is.na(t)) return(NA)
@@ -293,9 +293,9 @@ validate_import_time_mm_ss <- function(x, field_name, field_min, field_max, logf
     t <- as.numeric(t)
     t[1] * 60 + t[2]
   }
-  
+
   total_sec <- vapply(x, count_second, numeric(1))
-  
+
   print_validation_message(
     field_name,
     indices = which(total_sec < count_second(field_min)),
@@ -303,7 +303,7 @@ validate_import_time_mm_ss <- function(x, field_name, field_min, field_max, logf
                      field_min),
     logfile = logfile
   )
-  
+
   print_validation_message(
     field_name,
     indices = which(total_sec > count_second(field_max)),
@@ -311,7 +311,7 @@ validate_import_time_mm_ss <- function(x, field_name, field_min, field_max, logf
                      field_max),
     logfile = logfile
   )
-  
+
   print_validation_message(
     field_name,
     indices = which(w_invalid),
@@ -319,7 +319,7 @@ validate_import_time_mm_ss <- function(x, field_name, field_min, field_max, logf
                      "Values not imported"),
     logfile = logfile
   )
-  
+
   x
 }
 
@@ -334,13 +334,13 @@ validate_import_numeric <- function(x, field_name, field_min, field_max, logfile
 {
   suppressWarnings(num_check <- as.numeric(x))
   w <- which(is.na(num_check) & !x %in% c('', NA))
-  
+
   suppressWarnings({
     if (!is.numeric(x)) x <- as.numeric(x)
     field_min <- as.numeric(field_min)
     field_max <- as.numeric(field_max)
   })
-  
+
   print_validation_message(
     field_name,
     indices = which(x < field_min),
@@ -348,7 +348,7 @@ validate_import_numeric <- function(x, field_name, field_min, field_max, logfile
                      field_min),
     logfile = logfile
   )
-  
+
   print_validation_message(
     field_name,
     indices = which(x > field_max),
@@ -356,7 +356,7 @@ validate_import_numeric <- function(x, field_name, field_min, field_max, logfile
                      field_max),
     logfile = logfile
   )
-  
+
   print_validation_message(
     field_name,
     indices = w,
@@ -364,7 +364,7 @@ validate_import_numeric <- function(x, field_name, field_min, field_max, logfile
                      "Values not imported"),
     logfile = logfile
   )
-  
+
   x
 }
 
@@ -375,18 +375,18 @@ validate_import_numeric <- function(x, field_name, field_min, field_max, logfile
 # * Values that cannot be coerced to numeric produce a message
 # * values less than field_min produce a message
 # * values greater than field_max produce a message
-validate_import_ndp <- function(x, field_name, field_min, field_max, logfile, 
+validate_import_ndp <- function(x, field_name, field_min, field_max, logfile,
                                     ndp, comma = FALSE)
 {
   suppressWarnings(num_check <- as.numeric(x))
   w <- which(is.na(num_check) & !x %in% c('', NA))
-  
+
   suppressWarnings({
     if (!is.numeric(x)) x <- as.numeric(x)
     field_min <- as.numeric(field_min)
     field_max <- as.numeric(field_max)
   })
-  
+
   print_validation_message(
     field_name,
     indices = which(x < field_min),
@@ -394,7 +394,7 @@ validate_import_ndp <- function(x, field_name, field_min, field_max, logfile,
                      field_min),
     logfile = logfile
   )
-  
+
   print_validation_message(
     field_name,
     indices = which(x > field_max),
@@ -402,7 +402,7 @@ validate_import_ndp <- function(x, field_name, field_min, field_max, logfile,
                      field_max),
     logfile = logfile
   )
-  
+
   print_validation_message(
     field_name,
     indices = w,
@@ -410,11 +410,11 @@ validate_import_ndp <- function(x, field_name, field_min, field_max, logfile,
                      "Values not imported"),
     logfile = logfile
   )
-  
-  x[!is.na(x)] <- trimws(format(round(x[!is.na(x)], ndp), 
-                                nsmall = ndp, 
+
+  x[!is.na(x)] <- trimws(format(round(x[!is.na(x)], ndp),
+                                nsmall = ndp,
                                 decimal.mark = if (comma) "," else "."))
-  
+
   x
 }
 
@@ -428,9 +428,9 @@ validate_import_zipcode <- function(x, field_name, logfile)
   x <- as.character(x)
   x <- trimws(x)
   w <- which(!grepl("^(\\d{5}|\\d{5}-\\d{4})$", x) & !is.na(x))
-  
+
   x[w] <- rep(NA_character_, length(w))
-  
+
   print_validation_message(
     field_name,
     indices = w,
@@ -438,7 +438,7 @@ validate_import_zipcode <- function(x, field_name, logfile)
                      "Values not imported"),
     logfile = logfile
   )
-  
+
   x
 }
 
@@ -455,10 +455,10 @@ validate_import_yesno <- function(x, field_name, logfile)
   x <- tolower(x)
   w <- which(!x %in% c("no", "yes", "0", "1") & !is.na(x))
   x[w] <- rep(NA_character_, length(w))
-  
+
   x <- gsub("no", "0", x)
   x <- gsub("yes", "1", x)
-  
+
   print_validation_message(
     field_name,
     indices = w,
@@ -466,7 +466,7 @@ validate_import_yesno <- function(x, field_name, logfile)
                      "Values not imported"),
     logfile = logfile
   )
-  
+
   x
 }
 
@@ -482,7 +482,7 @@ validate_import_truefalse <- function(x, field_name, logfile)
   x <- as.character(x)
   x <- tolower(x)
   w <- which(!x %in% c("true", "false", "0", "1", "no", "yes") & !is.na(x))
-  
+
   print_validation_message(
     field_name,
     indices = w,
@@ -490,9 +490,9 @@ validate_import_truefalse <- function(x, field_name, logfile)
                      "Values not imported"),
     logfile = logfile
   )
-  
+
   x[w] <- NA
-  
+
   x <- gsub("(true|yes)", 1, x)
   x <- gsub("(false|no)", 0, x)
   x
@@ -507,16 +507,14 @@ validate_import_truefalse <- function(x, field_name, logfile)
 validate_import_select_dropdown_radio <- function(x, field_name, field_choice, logfile)
 {
   x <- as.character(x)
-  mapping <- fieldChoiceMapping(field_choice, field_name)  
-  
-  #* Return labeled values to coded values
-  for (i in seq_len(nrow(mapping))){
-    x[x == mapping[i, 2]] <- mapping[i, 1]  
-  }
-  
-  w <- which(!x %in% mapping[, 1] & !x %in% c('', NA))
-  x[w] <- rep(NA_character_, length(w))
-  
+  mapping <- fieldChoiceMapping(field_choice, field_name)
+
+  include <- !(x %in% c('', NA))
+  tomap   <- x %in% mapping[,2]
+  x[tomap] <- mapping[match(x[tomap], mapping[,2], NA_character_),1]
+  x[!tomap & include & !(x %in% mapping[,1])] <- NA_character_
+  w <- which(is.na(x) & include)
+
   print_validation_message(
     field_name,
     indices = w,
@@ -527,7 +525,7 @@ validate_import_select_dropdown_radio <- function(x, field_name, field_choice, l
                      "Values not imported"),
     logfile = logfile
   )
-  
+
   x
 }
 
@@ -540,12 +538,12 @@ validate_import_select_dropdown_radio <- function(x, field_name, field_choice, l
 validate_import_checkbox <- function(x, field_name, field_choice, logfile)
 {
   x <- trimws(tolower(as.character(x)))
-  
+
   checkChoice <- fieldChoiceMapping(field_choice, field_name)
-  
+
   #* Select the labeled string from the options as a valid input for the import.
   checkChoice <- checkChoice[checkChoice[, 1] == unlist(strsplit(field_name, "___"))[2], ]
-  
+
   w <- which(!x %in% c("checked", "unchecked", "0", "1", tolower(checkChoice), "", NA))
 
   x <- gsub("^checked$", "1", x)
@@ -554,24 +552,24 @@ validate_import_checkbox <- function(x, field_name, field_choice, logfile)
 
   x[x == ""] <- 0
   x[!x %in% c("0", "1")] <- NA
-  
+
   print_validation_message(
     field_name,
     indices = w,
     message = paste0("Value(s) must be one of '0', '1', 'Checked', 'Unchecked', '",
-                     paste0(checkChoice, collapse = "', '"), 
+                     paste0(checkChoice, collapse = "', '"),
                      "', '' (ignoring case).\n",
                      "Values not imported"),
     logfile = logfile
   )
-  
+
   x
 }
 
 # validate_import_email ---------------------------------------------
 # Tests to run
 # * Common email addresses pass
-# * Invalid e-mail addresses are changed to NA 
+# * Invalid e-mail addresses are changed to NA
 #     - have more than one @
 #     - have no @
 #     - have no suffix
@@ -584,7 +582,7 @@ validate_import_email <- function(x, field_name, logfile)
   x <- as.character(x)
   w <- which((!grepl("[A-Za-z0-9._%+-]+@[A-Za-z0-9.-]+[.][A-Za-z]{2,6}$", x) |
                 grepl("[@].+[@]", x)) & !is.na(x))
-  
+
   print_validation_message(
     field_name = field_name,
     indices = w,
@@ -592,9 +590,9 @@ validate_import_email <- function(x, field_name, logfile)
                      "Values not imported."),
     logfile = logfile
   )
-  
+
   x[w] <- NA
-  
+
   x
 }
 
@@ -611,27 +609,27 @@ validate_import_phone <- function(x, field_name, logfile)
 {
   x <- as.character(x)
   x <- gsub("[[:punct:][:space:]]", "", x)
-  
+
   w_long <- nchar(x) != 10 & !is.na(x)
-  
+
   w_invalid <- !grepl("^[2-9][0-8][0-9][2-9][0-9]{6}$", x) & !is.na(x)
-  
+
   print_validation_message(
     field_name = field_name,
     indices = which(w_long),
     message = paste0("Value(s) are not ten digit phone numbers.\n",
-                     "Values not imported."), 
+                     "Values not imported."),
     logfile = logfile
   )
-  
+
   print_validation_message(
     field_name = field_name,
     indices = which(w_invalid),
     message = paste0("Value(s) are not valid North American phone numbers.\n",
-                     "Values not imported."), 
+                     "Values not imported."),
     logfile = logfile
   )
-  
+
   x[w_long | w_invalid] <- NA_character_
   x
 }
@@ -642,19 +640,19 @@ print_validation_message <- function(field_name, indices, message, logfile)
 {
   if (length(indices))
   {
-    message <- 
+    message <-
       paste0("------------------------------------\n",
              "Field Name: `", field_name, "`\n",
              "Indices: ", paste0(indices, collapse = ", "), "\n",
              message, "\n\n")
-    
+
     if (logfile == "")
     {
       message(message)
     }
-    else  
+    else
     {
-      write(message, 
+      write(message,
             file = logfile,
             append = TRUE)
     }
