@@ -13,13 +13,10 @@ test_that(
 )
 
 test_that(
-  "Validate error_handling, config, api_param", 
+  "Validate config, api_param", 
   {
     local_reproducible_output(width = 200)
-    expect_error(exportProjectInformation(rcon, 
-                                          error_handling = "not an option"), 
-                 "'error[_]handling': Must be element of set [{]'null','error'[}]")
-    
+
     expect_error(exportProjectInformation(rcon, 
                                           config = list(1)), 
                  "'config': Must have names")
@@ -63,15 +60,10 @@ test_that(
 )
 
 test_that(
-  "Validate error_handling, config, api_param", 
+  "Validate config, api_param", 
   {
     local_reproducible_output(width = 200)
     
-    expect_error(importProjectInformation(rcon, 
-                                          data = NewInfo, 
-                                          error_handling = "not an option"), 
-                 "'error[_]handling': Must be element of set [{]'null','error'[}]")
-    
     expect_error(importProjectInformation(rcon, 
                                           data = NewInfo, 
                                           config = list(1)), 
