@@ -39,13 +39,10 @@ test_that(
 )
 
 test_that(
-  "Validate error_handling, config, api_param", 
+  "Validate config, api_param", 
   {
     local_reproducible_output(width = 200)
-    expect_error(exportUserRoles(rcon, 
-                                 error_handling = "not an option"), 
-                 "'error[_]handling': Must be element of set [{]'null','error'[}]")
-    
+   
     expect_error(exportUserRoles(rcon, 
                                  config = list(1)), 
                  "'config': Must have names")
@@ -70,7 +67,7 @@ test_that(
   {
     local_reproducible_output(width = 200)
     expect_error(importUserRoles("not an rcon", 
-                                 data = REDCAP_USER_ROLE_STRUCTURE), 
+                                 data = redcapUserRoleStructure(rcon$version())), 
                  "no applicable method for 'importUserRoles'")
   }
 )
@@ -94,11 +91,11 @@ test_that(
   {
     local_reproducible_output(width = 200)
     expect_error(importUserRoles(rcon, 
-                                 data = REDCAP_USER_ROLE_STRUCTURE,
+                                 data = redcapUserRoleStructure(rcon$version()),
                                  consolidate = "TRUE"), 
                  "'consolidate': Must be of type 'logical'")
     expect_error(importUserRoles(rcon, 
-                                 data = REDCAP_USER_ROLE_STRUCTURE,
+                                 data = redcapUserRoleStructure(rcon$version()),
                                  consolidate = c(TRUE, FALSE)), 
                  "'consolidate': Must have length 1")
   }
@@ -106,29 +103,25 @@ test_that(
 
 
 test_that(
-  "Validate error_handling, config, api_param", 
+  "Validate config, api_param", 
   {
     local_reproducible_output(width = 200)
+   
     expect_error(importUserRoles(rcon, 
-                                 data = REDCAP_USER_ROLE_STRUCTURE,
-                                 error_handling = "not an option"), 
-                 "'error[_]handling': Must be element of set [{]'null','error'[}]")
-    
-    expect_error(importUserRoles(rcon, 
-                                 data = REDCAP_USER_ROLE_STRUCTURE,
+                                 data = redcapUserRoleStructure(rcon$version()),
                                  config = list(1)), 
                  "'config': Must have names")
     expect_error(importUserRoles(rcon, 
-                                 data = REDCAP_USER_ROLE_STRUCTURE,
+                                 data = redcapUserRoleStructure(rcon$version()),
                                  config = "not a list"), 
                  "'config': Must be of type 'list'")
     
     expect_error(importUserRoles(rcon, 
-                                 data = REDCAP_USER_ROLE_STRUCTURE,
+                                 data = redcapUserRoleStructure(rcon$version()),
                                  api_param = list(1)), 
                  "'api_param': Must have names")
     expect_error(importUserRoles(rcon, 
-                                 data = REDCAP_USER_ROLE_STRUCTURE,
+                                 data = redcapUserRoleStructure(rcon$version()),
                                  api_param = "not a list"), 
                  "'api_param': Must be of type 'list'")
   }
@@ -157,31 +150,3 @@ test_that(
   }
 )
 
-test_that(
-  "Validate error_handling, config, api_param", 
-  {
-    local_reproducible_output(width = 200)
-    expect_error(deleteUserRoles(rcon, 
-                                 user_roles = "user-role",
-                                 error_handling = "not an option"), 
-                 "'error[_]handling': Must be element of set [{]'null','error'[}]")
-    
-    expect_error(deleteUserRoles(rcon, 
-                                 user_roles = "user-role",
-                                 config = list(1)), 
-                 "'config': Must have names")
-    expect_error(deleteUserRoles(rcon, 
-                                 user_roles = "user-role",
-                                 config = "not a list"), 
-                 "'config': Must be of type 'list'")
-    
-    expect_error(deleteUserRoles(rcon, 
-                                 user_roles = "user-role",
-                                 api_param = list(1)), 
-                 "'api_param': Must have names")
-    expect_error(deleteUserRoles(rcon, 
-                                 user_roles = "user-role",
-                                 api_param = "not a list"), 
-                 "'api_param': Must be of type 'list'")
-  }
-)
