@@ -7,6 +7,7 @@ context("Export Typed Records Functionality")
 #
 # Subsequent files will deal with each of those specifics
 
+purgeProject(rcon, records=TRUE)
 load(file.path(test_path("testdata"),
                "test_redcapAPI_MetaData.Rdata"))
 load(file.path(test_path("testdata"), 
@@ -16,20 +17,14 @@ load(file.path(test_path("testdata"),
 load(file.path(test_path("testdata"), 
                "test_redcapAPI_Events.Rdata"))
 
-rcon$flush_all()
-
 forms <- c("record_id", "text_fields", "dates_and_times", "numbers", 
            "slider_fields", "multiple_choice", 
            "files_notes_descriptions", "calculated_fields")
 MetaData <- test_redcapAPI_MetaData[test_redcapAPI_MetaData$form_name %in% forms, ]
 
-importMetaData(rcon, 
-               MetaData)
-importArms(rcon, 
-           data = test_redcapAPI_Arms)
-importEvents(rcon, 
-             data = test_redcapAPI_Events)
-
+importMetaData(rcon, MetaData)
+importArms(rcon,     test_redcapAPI_Arms)
+importEvents(rcon,   test_redcapAPI_Events)
 importProjectInformation(rcon, 
                          data.frame(is_longitudinal = 1, 
                                     record_autonumbering_enabled = 0))
@@ -37,8 +32,7 @@ importProjectInformation(rcon,
 Mappings <- data.frame(arm_num = rep(1, length(forms)), 
                        unique_event_name = rep("event_1_arm_1", length(forms)), 
                        form = forms)
-importMappings(rcon, 
-               data = Mappings)
+importMappings(rcon, Mappings)
 
 
 ImportData <- test_redcapAPI_Data[names(test_redcapAPI_Data) %in% MetaData$field_name]
@@ -54,9 +48,8 @@ ImportData <- castForImport(ImportData,
                                         bioportal = as.character))
 
 
-importRecords(rcon, 
-              ImportData)
-rcon$flush_externalCoding()
+importRecords(rcon, ImportData)
+
 
 #####################################################################
 # Functional Testing                                             ####
@@ -244,12 +237,10 @@ test_that(
 test_that(
   "Calculated fields are exported", 
   {
-    expect_data_frame(
-      exportRecordsTyped(rcon, 
-                         fields = c("left_operand", "right_operand", 
-                                    "calc_addition", "calc_squared")), 
-      ncols = 6
-    )
+    fields <- c("left_operand", "right_operand","calc_addition", "calc_squared")
+    expect_data_frame(x <- exportRecordsTyped(rcon, fields = fields), 
+                      min.cols = 6)
+    expect_subset(fields, names(x))
   }
 )
 
@@ -324,7 +315,6 @@ test_that(
     NewMetaData$select_choices_or_calculations[2] <- "0, Zero | 1, One | 2, Two"
     
     importMetaData(rcon, NewMetaData)
-    rcon$refresh_fieldnames()
     
     importRecords(rcon, 
                   data = data.frame(record_id = 1:4,
@@ -468,7 +458,6 @@ test_that(
     
     # Restore the meta data for further testing ---------------------
     importMetaData(rcon, MetaData)
-    rcon$refresh_fieldnames()
   }
 )
 
