@@ -87,6 +87,35 @@ test_that(
                          dir_create = TRUE,
                          recursive = TRUE)
     
+    local_reproducible_output(width = 200)
+   
+    expect_error(deleteFileRepository(rcon, 
+                                      folder_id = 0, 
+                                      recursive = TRUE, 
+                                      confirm = "yes",
+                                      config = list(1)), 
+                 "'config': Must have names")
+    expect_error(deleteFileRepository(rcon, 
+                                      folder_id = 0, 
+                                      recursive = TRUE, 
+                                      confirm = "yes",
+                                      config = "not a list"), 
+                 "'config': Must be of type 'list'")
+    
+    expect_error(deleteFileRepository(rcon, 
+                                      folder_id = 0, 
+                                      recursive = TRUE, 
+                                      confirm = "yes",
+                                      api_param = list(1)), 
+                 "'api_param': Must have names")
+    expect_error(deleteFileRepository(rcon, 
+                                      folder_id = 0, 
+                                      recursive = TRUE, 
+                                      confirm = "yes",
+                                      api_param = "not a list"), 
+                 "'api_param': Must be of type 'list'")
+    
+    
     Deleted <- deleteFileRepository(rcon, 
                                     folder_id = 0, 
                                     recursive = TRUE, 
